@@ -49,7 +49,7 @@ class HttpDownloaderTest extends TestCase
         try {
             $fs->get('https://user:pass@github.com/composer/composer/404');
         } catch (\Composer\Downloader\TransportException $e) {
-            $this->assertNotEquals(200, $e->getCode());
+            self::assertNotEquals(200, $e->getCode());
         }
     }
 
@@ -57,7 +57,7 @@ class HttpDownloaderTest extends TestCase
     {
         $io = new BufferIO();
         HttpDownloader::outputWarnings($io, '$URL', []);
-        $this->assertSame('', $io->getOutput());
+        self::assertSame('', $io->getOutput());
         HttpDownloader::outputWarnings($io, '$URL', [
             'warning' => 'old warning msg',
             'warning-versions' => '>=2.0',
@@ -74,7 +74,7 @@ class HttpDownloaderTest extends TestCase
         ]);
 
         // the <info> tag are consumed by the OutputFormatter, but not <warning> as that is not a default output format
-        $this->assertSame(
+        self::assertSame(
             '<warning>Warning from $URL: old warning msg</warning>'.PHP_EOL.
             'Info from $URL: old info msg'.PHP_EOL.
             '<warning>Warning from $URL: visible warning</warning>'.PHP_EOL.
